﻿function Get-TransJobs
{
    [CmdletBinding(SupportsShouldProcess=$true, 
                  PositionalBinding=$false,
                  ConfirmImpact='Medium')]
    [Alias()]
    [OutputType([PSOBJECT])]

    param (
        [Parameter(Mandatory=$True, ParameterSetName='ELHC')]
        [ValidateNotNullOrEmpty()]
        [PSObject]$ELHCConfig = $false,

        [Parameter(Mandatory=$False, ParameterSetName='External')]
        [ValidateNotNullOrEmpty()]
        [string]$ConnectionString = "data source=(local);initial catalog=WGEvidenceLibrary;integrated security=true;connection lifetime=30;"
    )

    if($ELHCConfig) {
        $ConnectionString = $ELHCConfig.root.ConnectionString
    }

    $Query = "select COUNT(*) as Pending from JobQueue.TranscodeQueue WHERE SubstationID = '$($ELHCConfig.root.substationID)'"

    $TranscodeCount = (Get-QueryResult -query $Query -connectionString $ConnectionString).Pending

    $AlertBool = $false
    $AlertJobs = [int]$ELHCConfig.root.components.standalone.component.transjobs.alerts.allowedjobs
    if ($AlertJobs -lt $TranscodeCount) {
        $AlertBool = $true
    }

    $Results = @{
        'LogType' = "TransJobs"
        'TranscodesPending' = $TranscodeCount
        'AlertJobs' = $AlertJobs
        'AlertBool' = $AlertBool
    }

    return $Results
}